/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2016 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  16.10.2016  mifi  First Version for the SAM D21 Xplained Pro board.
**************************************************************************/
#if !defined(__TALBOARD_H__) && defined(USE_BOARD_SAMD21XPRO)
#define __TALBOARD_H__

/**************************************************************************
*  Includes
**************************************************************************/
#include <stdint.h>
#include <stdbool.h>
#include "project.h"
#include "taltypes.h"

#include "samd21.h"

/**************************************************************************
*  Global Definitions
**************************************************************************/

/*
 * Defines for board and cpu name
 */
#define TAL_BOARD "ATSAMD21-XPRO"
#define TAL_CPU   "ATSAMD21J18A"


/*
 * Check CPU_FREQUENCY value, mut be 8MHz or 48MHz
 */
#if ((CPU_FREQUENCY != 8000000) && (CPU_FREQUENCY != 48000000))
   Error: CPU_FREQUENCY must defined to 8000000 or 48000000 by the preprocessor;
#endif

 
/*
 * With 2 bits of interrupt priority 4 levels are
 * available. Priority 0 is the highest one, 3 the lowest.
 */

#ifndef SYSTICK_PRIO
#define SYSTICK_PRIO    0
#endif 

#ifndef SERCOM0_PRIO
#define SERCOM0_PRIO    3
#endif

#ifndef SERCOM1_PRIO
#define SERCOM1_PRIO    3
#endif

#ifndef SERCOM2_PRIO
#define SERCOM2_PRIO    3
#endif

#ifndef SERCOM3_PRIO
#define SERCOM3_PRIO    3
#endif

#ifndef SERCOM4_PRIO
#define SERCOM4_PRIO    3
#endif

#ifndef SERCOM5_PRIO
#define SERCOM5_PRIO    3
#endif


/*
 * The SAM D20 Xplained Pro board support 1 LED
 */
typedef enum _tal_led_channel_
{
   TAL_LED_CHANNEL_1 = 0,
   
   /* TAL_LED_CHANNEL_MAX must be the last one */
   TAL_LED_CHANNEL_MAX
} TAL_LED_CHANNEL;

/*
 * LED name from the board itself
 */
#define LED0   TAL_LED_CHANNEL_1


/*
 * COM port used for the terminal, SERCOM3 = PORT4
 */
#if !defined(TERM_COM_PORT)
#define TERM_COM_PORT   TAL_COM_PORT_4
#endif

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

TAL_RESULT tal_BoardEnableCOM1(void);
TAL_RESULT tal_BoardEnableCOM2(void);
TAL_RESULT tal_BoardEnableCOM3(void);
TAL_RESULT tal_BoardEnableCOM4(void);
TAL_RESULT tal_BoardEnableCOM5(void);
TAL_RESULT tal_BoardEnableCOM6(void);

#endif /* !__TALBOARD_H__ */

/*** EOF ***/
