/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2013-2016 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  19.05.2013  mifi  First Version.
*  16.06.2016  mifi  Added Cortex-M0+ support.
**************************************************************************/
#if !defined(__TALCPU_H__)
#define __TALCPU_H__

/**************************************************************************
*  Includes
**************************************************************************/
#include "talos.h"
#include "talcpu_specific.h"

/*
 * Check for ARM7 style CPU
 */
#if defined(__ARM_ARCH_4T__)
#include "talcpu_arm.h"
#endif

/*
 * Check for Cortex-M and Cortex-M0 style CPU
 */
#if defined(__ARM_ARCH_7EM__) || defined(__ARM_ARCH_7M__) || defined(__ARM_ARCH_6M__)
#include "talcpu_cm.h"
#endif

/**************************************************************************
*  Global Definitions
**************************************************************************/

typedef void (*tal_irq_fnt)(void);

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

void     tal_CPUInit (void);
void     tal_CPUSysTickStart (void);

void     tal_CPUIrqEnable (int IRQ);
void     tal_CPUIrqDisable (int IRQ);
void     tal_CPUIrqDisableAll (void);
void     tal_CPUIrqSetPriority (int IRQ, int Priority);
void     tal_CPUIrqSetFunction (int IRQ, tal_irq_fnt Function);

uint32_t tal_CPUStatGetHiResPeriod (void);
uint32_t tal_CPUStatGetHiResCnt (void);

uint32_t tal_CPUGetFrequencyCPU (void);

#endif /* !__TALCPU_H__ */

/*** EOF ***/
